#ifndef NT2_INCLUDE_FUNCTIONS_CLEMENT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CLEMENT_HPP_INCLUDED

#include <nt2/gallery/include/functions/clement.hpp>

#endif
